@@ -2,11 +2,6 @@ if (test_srcs$length() == 0) {
 
   test_register_src("df", dplyr::src_df(env = new.env(parent = emptyenv())))
   test_register_con("sqlite", RSQLite::SQLite(), ":memory:")
-  test_register_con("mysql", RMySQL::MySQL(),
-    dbname = "test",
-    host = "localhost",
-    user = Sys.getenv("USER")
-  )
 
   if (identical(Sys.getenv("TRAVIS"), "true")) {
     test_register_con("postgres", RPostgreSQL::PostgreSQL(),
@@ -15,6 +10,16 @@ if (test_srcs$length() == 0) {
       password = ""
     )
   } else {
+    test_register_con("mysql", RMySQL::MySQL(),
+      dbname = "test",
+      host = "localhost",
+      user = Sys.getenv("USER")
+    )
+    test_register_con("MariaDB", RMariaDB::MariaDB(),
+      dbname = "test",
+      host = "localhost",
+      user = Sys.getenv("USER")
+    )
     test_register_con("postgres", RPostgreSQL::PostgreSQL(),
       dbname = "test",
       host = "localhost",
@@ -23,7 +28,7 @@ if (test_srcs$length() == 0) {
   }
 }
 
-skip_if_no_sqlite <- function() {
-  if (!test_srcs$has("sqlite"))
-    skip("No SQLite")
+skip_if_no_db <- function(db) {
+  if (!test_srcs$has(db))
+    skip(paste0("No ", db))
 }
